"use client";

import React, { useState } from "react";
import { ScrollArea } from "@/components/ui/scroll-area";
import {
  ResizableHandle,
  ResizablePanel,
  ResizablePanelGroup,
} from "@/components/ui/resizable";
import markdownStyles from "@/styles/markdown-styles.module.css";
import { tutorialData } from "@/constants/tutorial-data";
import { notFound } from "next/navigation";
import { Button, buttonVariants } from "@/components/ui/button";
import Link from "next/link";
import { cn } from "@/lib/utils";
import EditorWindow from "@/components/task/editor-window";
import { LANGUAGE_VERSIONS } from "@/constants/language-options";
import { markdownToHtml } from "@/lib/markdown-to-html";
import Header from "./task/header";
import Image from "next/image";
import ThemeToggle from "./layout/ThemeToggle/theme-toggle";

const languages = Object.keys(LANGUAGE_VERSIONS);

interface LangTutorial {
  id: number;
  language: string;
  tutorial: {
    id: number;
    content: string;
    code: string;
  }[];
}

interface Tutorial {
  id: number;
  content: string;
  code: string;
}

const TaskPage = ({
  params,
  langTutorial,
  tutorial,
  tutorialIndex,
  content,
}: {
  params: { taskId: string[] };
  langTutorial: LangTutorial;
  tutorial: Tutorial;
  tutorialIndex: number;
  content: string;
}) => {
  const [activeMobileView, setActiveMobileView] = useState<
    "tutorial" | "code" | "output"
  >("tutorial");

  //   if (!params.taskId[0] || !languages.includes(params.taskId[0])) {
  //     notFound();
  //   }

  //   const langTutorial = tutorialData.find(
  //     (t) => t.language === params.taskId[0],
  //   )!;

  //   const tutorial = langTutorial.tutorial.find(
  //     (t) => t.id === (Number(params.taskId[1]) || 1),
  //   );

  //   const tutorialIndex = langTutorial.tutorial.findIndex(
  //     (t) => t.id === (Number(params.taskId[1]) || 1),
  //   );

  //   if (!tutorial || tutorialIndex === -1) {
  //     notFound();
  //   }

  //   const content = await markdownToHtml(tutorial?.content || "");
  return (
    <>
      <div className="flex md:hidden items-center justify-center gap-4 fixed md:static w-screen bottom-0 left-0 z-50 px-4 py-3 bg-background border-t">
        <Button
          variant={activeMobileView === "tutorial" ? "default" : "outline"}
          onClick={() => setActiveMobileView("tutorial")}
        >
          Tutorial
        </Button>
        <Button
          variant={activeMobileView === "code" ? "default" : "outline"}
          onClick={() => setActiveMobileView("code")}
        >
          Code
        </Button>
        <Button
          variant={activeMobileView === "output" ? "default" : "outline"}
          onClick={() => setActiveMobileView("output")}
        >
          Output
        </Button>
      </div>
      <div className="md:hidden w-full h-full">
        {/* <ResizablePanelGroup
          direction="vertical"
          className="max-w-[1440px] mx-auto h-full"
        > */}
        {/* <ResizablePanel defaultSize={50}> */}
        <div
          className={cn(
            "fixed left-0 top-0 h-[calc(100vh-59px)] w-screen transition-transform translate-x-0",
            activeMobileView === "tutorial"
              ? "translate-x-0"
              : activeMobileView === "code"
              ? "-translate-x-full"
              : activeMobileView === "output"
              ? "-translate-x-[200%]"
              : "",
          )}
        >
          <div className="border-b px-4 bg-background">
            <nav className="flex justify-between items-center max-w-[1440px] mx-auto py-2">
              <Link href="/dashboard" className="inline-block w-fit">
                <Image
                  src="/Skilld AI Logos/Skilld Logo-colour on black.png"
                  alt="Skilld Logo"
                  width={100}
                  height={30}
                  className="hidden dark:block h-[25px] w-[80px] md:w-[100px] md:h-[30px] object-contain"
                />
                <Image
                  src="/Skilld AI Logos/Skilld Logo-colour.png"
                  alt="Skilld Logo"
                  width={100}
                  height={30}
                  className="dark:hidden h-[25px] w-[80px] md:w-[100px] md:h-[30px] object-contain"
                />
              </Link>

              <div className="flex items-center gap-8">
                {/* <Link href="/">Home</Link> */}
                <Link href="/dashboard">Dashboard</Link>
                {/* <Link href="/login">Login</Link> */}
                <ThemeToggle />
              </div>
            </nav>
          </div>

          <ScrollArea className="h-[calc(100vh-calc(53px+59px))]">
            <div className="p-4 flex flex-col gap-4 h-full">
              <div
                className={cn("grow", markdownStyles["markdown"])}
                dangerouslySetInnerHTML={{ __html: content }}
              ></div>
              <div className="flex justify-between">
                <div className="mb-6">
                  {langTutorial?.tutorial[tutorialIndex - 1] && (
                    <Link
                      href={`/dashboard/task/${params.taskId[0]}/${
                        Number(params.taskId[1]) - 1
                      }`}
                      className={buttonVariants({
                        variant: "outline",
                      })}
                    >
                      Prev
                    </Link>
                  )}
                </div>

                <div className="mb-6">
                  {langTutorial?.tutorial[tutorialIndex + 1] && (
                    <Link
                      href={`/dashboard/task/${params.taskId[0]}/${
                        Number(params.taskId[1]) + 1
                      }`}
                      className={buttonVariants({
                        variant: "outline",
                      })}
                    >
                      Next
                    </Link>
                  )}
                </div>
              </div>
            </div>
          </ScrollArea>
        </div>
        {/* </ResizablePanel> */}
        {/* <ResizableHandle withHandle /> */}
        {/* <ResizablePanel defaultSize={50}> */}
        <EditorWindow
          activeMobileView={activeMobileView}
          language={params.taskId[0]}
          step={Number(params.taskId[1]) || 1}
        />
        {/* </ResizablePanel> */}
        {/* </ResizablePanelGroup> */}
      </div>
      {/* <div className="md:hidden w-full h-full">
        <ResizablePanelGroup
          direction="vertical"
          className="max-w-[1440px] mx-auto h-full"
        >
          <ResizablePanel defaultSize={50}>
            <ScrollArea className="h-[calc(100vh-55px)]">
              <div className="px-4 py-6 flex flex-col gap-4 h-full mb-[60vh]">
                <div
                  className={cn("grow", markdownStyles["markdown"])}
                  dangerouslySetInnerHTML={{ __html: content }}
                ></div>
                <div className="flex justify-between">
                  <div className="mb-6">
                    {langTutorial?.tutorial[tutorialIndex - 1] && (
                      <Link
                        href={`/dashboard/task/${params.taskId[0]}/${
                          Number(params.taskId[1]) - 1
                        }`}
                        className={buttonVariants({
                          variant: "outline",
                        })}
                      >
                        Prev
                      </Link>
                    )}
                  </div>

                  <div className="mb-6">
                    {langTutorial?.tutorial[tutorialIndex + 1] && (
                      <Link
                        href={`/dashboard/task/${params.taskId[0]}/${
                          Number(params.taskId[1]) + 1
                        }`}
                        className={buttonVariants({ variant: "outline" })}
                      >
                        Next
                      </Link>
                    )}
                  </div>
                </div>
              </div>
            </ScrollArea>
          </ResizablePanel>
          <ResizableHandle withHandle />
          <ResizablePanel defaultSize={50}>
            <EditorWindow
              language={params.taskId[0]}
              step={Number(params.taskId[1]) || 1}
            />
          </ResizablePanel>
        </ResizablePanelGroup>
      </div> */}
      <div className="hidden md:block w-full h-full">
        <ResizablePanelGroup
          direction="horizontal"
          className="max-w-[1440px] mx-auto h-full"
        >
          <ResizablePanel defaultSize={50}>
            <ScrollArea className="h-[calc(100vh-55px)]">
              <div className="px-4 py-6 flex flex-col gap-4 h-full">
                <div
                  className={cn("grow", markdownStyles["markdown"])}
                  dangerouslySetInnerHTML={{ __html: content }}
                ></div>

                <div className="flex justify-between">
                  <div className="mb-6">
                    {langTutorial?.tutorial[tutorialIndex - 1] && (
                      <Link
                        href={`/dashboard/task/${params.taskId[0]}/${
                          Number(params.taskId[1]) - 1
                        }`}
                        className={buttonVariants({
                          variant: "outline",
                        })}
                      >
                        Prev
                      </Link>
                    )}
                  </div>

                  <div className="mb-6">
                    {langTutorial?.tutorial[tutorialIndex + 1] && (
                      <Link
                        href={`/dashboard/task/${params.taskId[0]}/${
                          Number(params.taskId[1]) + 1
                        }`}
                        className={buttonVariants({ variant: "outline" })}
                      >
                        Next
                      </Link>
                    )}
                  </div>
                </div>
              </div>
            </ScrollArea>
          </ResizablePanel>
          <ResizableHandle withHandle />
          <ResizablePanel defaultSize={50}>
            <EditorWindow
              activeMobileView={activeMobileView}
              language={params.taskId[0]}
              step={Number(params.taskId[1]) || 1}
            />
          </ResizablePanel>
        </ResizablePanelGroup>
      </div>
    </>
  );
};

export default TaskPage;
